Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type OAuthService ¶
type OAuthService interface {
//VerifyOAuth verify the oAuth tokens and permissions
VerifyOAuth(next http.Handler) http.Handler
}
OAuthService the service for verifying OAuth keys
func CreateApigeeOAuth ¶
func CreateApigeeOAuth(keyURL string) OAuthService
CreateApigeeOAuth create an apigee instance of the oauth service
type Principal ¶
type Principal interface {
//return the identifier of the principal. This should be an immutable value for the principal, otherwise future access to assets is not gaurenteed
GetSubject() (string, error)
}
Principal the principal of the JWT token. This interface primarily exists as a means of decoupling auth during the api testing
Click to show internal directories.
Click to hide internal directories.